@@ -151,6 +151,7 @@ PhoshMonitorMode * phosh_monitor_get_current_mode (PhoshMonitor *self);
 gboolean           phosh_monitor_is_configured (PhoshMonitor *self);
 gboolean           phosh_monitor_is_builtin (PhoshMonitor *self);
 gboolean           phosh_monitor_is_flipped (PhoshMonitor *self);
+gboolean           phosh_monitor_has_gamma (PhoshMonitor *self);
 guint              phosh_monitor_get_transform (PhoshMonitor *self);
 void               phosh_monitor_set_power_save_mode (PhoshMonitor *self,
                                                       PhoshMonitorPowerSaveMode mode);
@@ -160,4 +161,6 @@ gboolean           phosh_monitor_connector_is_builtin (PhoshMonitorConnectorType
 struct wl_output * phosh_monitor_get_wl_output (PhoshMonitor *self);
 float              phosh_monitor_get_fractional_scale (PhoshMonitor *self);
 
+gboolean           phosh_monitor_transform_is_tilted (PhoshMonitorTransform transform);
+
 G_END_DECLS
