@@ -6,11 +6,11 @@
 
 #pragma once
 
-#include "layersurface.h"
+#include "drag-surface.h"
 
 #define PHOSH_TYPE_TOP_PANEL            (phosh_top_panel_get_type ())
 
-G_DECLARE_FINAL_TYPE (PhoshTopPanel, phosh_top_panel, PHOSH, TOP_PANEL, PhoshLayerSurface)
+G_DECLARE_FINAL_TYPE (PhoshTopPanel, phosh_top_panel, PHOSH, TOP_PANEL, PhoshDragSurface)
 
 #define PHOSH_TOP_PANEL_HEIGHT 32
 
@@ -24,8 +24,11 @@ typedef enum {
   PHOSH_TOP_PANEL_STATE_UNFOLDED,
 } PhoshTopPanelState;
 
-GtkWidget         *phosh_top_panel_new (struct zwlr_layer_shell_v1 *layer_shell,
-                                        struct wl_output           *wl_output);
+GtkWidget         *phosh_top_panel_new (struct zwlr_layer_shell_v1          *layer_shell,
+                                        struct zphoc_layer_shell_effects_v1 *layer_shell_effects,
+                                        struct wl_output                    *wl_output,
+                                        guint32                              layer,
+                                        int                                  height);
 void               phosh_top_panel_toggle_fold (PhoshTopPanel *self);
 void               phosh_top_panel_fold (PhoshTopPanel *self);
 void               phosh_top_panel_unfold (PhoshTopPanel *self);
