@@ -1,22 +1,11 @@
 /*
- * Copyright (C) 2021 Purism SPC
+ * Copyright (C) 2021, 2022 Purism SPC
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * Calls is free software: you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * Calls is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Calls.  If not, see <http://www.gnu.org/licenses/>.
- *
  * Author: Guido Günther <agx@sigxcpu.org>
+ *         Evangelos Ribeiro Tzaras <devrtz@fortysixandtwo.eu>
+ *
  * Somewhat based on call's call-display by:
  * Author: Bob Ham <bob.ham@puri.sm>
  */
@@ -24,6 +13,7 @@
 #include "config.h"
 
 #include "cui-call-display.h"
+#include "cui-encryption-indicator-priv.h"
 
 #include "cui-call.h"
 
@@ -34,6 +24,9 @@
 
 #define IS_NULL_OR_EMPTY(x)  ((x) == NULL || (x)[0] == '\0')
 
+#define HDY_AVATAR_SIZE_BIG 160
+#define HDY_AVATAR_SIZE_DEFAULT 80
+
 /**
  * CuiCallDisplay:
  *
@@ -50,31 +43,36 @@ enum {
 static GParamSpec *props[PROP_LAST_PROP];
 
 struct _CuiCallDisplay {
-  GtkOverlay       parent_instance;
+  GtkOverlay              parent_instance;
 
-  CuiCall         *call;
+  CuiCall                *call;
 
-  GtkLabel        *incoming_phone_call;
-  HdyAvatar       *avatar;
-  GtkLabel        *primary_contact_info;
-  GtkLabel        *secondary_contact_info;
-  GtkLabel        *status;
+  GtkLabel               *incoming_phone_call;
+  HdyAvatar              *avatar;
+  GtkLabel               *primary_contact_info;
+  GtkLabel               *secondary_contact_info;
+  GtkLabel               *status;
 
-  GtkBox          *controls;
-  GtkBox          *gsm_controls;
-  GtkBox          *general_controls;
-  GtkToggleButton *speaker;
-  GtkToggleButton *mute;
-  GtkButton       *hang_up;
-  GtkButton       *answer;
+  GtkBox                 *controls;
+  GtkBox                 *gsm_controls;
+  GtkBox                 *general_controls;
+  GtkToggleButton        *speaker;
+  GtkToggleButton        *mute;
+  GtkButton              *hang_up;
+  GtkButton              *answer;
+  CuiEncryptionIndicator *encryption_indicator;
 
-  GCancellable    *cancel;
-  GtkRevealer     *dial_pad_revealer;
-  GtkToggleButton *dial_pad;
-  GtkEntry        *keypad_entry;
+  GCancellable           *cancel;
+  GtkRevealer            *dial_pad_revealer;
+  GtkToggleButton        *dial_pad;
+  GtkEntry               *keypad_entry;
 
-  GBinding        *dtmf_bind;
-  GBinding        *avatar_icon_bind;
+  GBinding               *dtmf_bind;
+  GBinding               *avatar_icon_bind;
+  GBinding               *encryption_bind;
+
+  gboolean                needs_cam_reset; /* cam = Call Audio Mode */
+  gboolean                update_status_time;
 };
 
 G_DEFINE_TYPE (CuiCallDisplay, cui_call_display, GTK_TYPE_OVERLAY);
@@ -97,6 +95,12 @@ on_answer_clicked (CuiCallDisplay *self)
 {
   g_return_if_fail (CUI_IS_CALL_DISPLAY (self));
 
+  self->update_status_time = FALSE;
+  gtk_label_set_label (self->status,
+                       _("Accepting call…"));
+
+  gtk_widget_set_sensitive (GTK_WIDGET (self->answer), FALSE);
+
   cui_call_accept (self->call);
 }
 
@@ -106,15 +110,23 @@ on_hang_up_clicked (CuiCallDisplay *self)
 {
   g_return_if_fail (CUI_IS_CALL_DISPLAY (self));
 
+  self->update_status_time = FALSE;
+  gtk_label_set_label (self->status,
+                       _("Hanging up…"));
+
+  gtk_widget_set_sensitive (GTK_WIDGET (self->hang_up), FALSE);
+
   cui_call_hang_up (self->call);
 }
 
+
 static void
 hold_toggled_cb (GtkToggleButton *togglebutton,
                  CuiCallDisplay  *self)
 {
 }
 
+
 static void
 mute_toggled_cb (GtkToggleButton *togglebutton,
                  CuiCallDisplay  *self)
@@ -169,16 +181,16 @@ set_pretty_time (CuiCallDisplay *self)
   str = g_string_new ("");
 
   if (elapsed > HOUR) {
-    guint hours = (guint)(elapsed / HOUR);
+    guint hours = (guint) (elapsed / HOUR);
     g_string_append_printf (str, "%u:", hours);
     elapsed -= (hours * HOUR);
   }
 
-  minutes = (guint)(elapsed / MINUTE);
+  minutes = (guint) (elapsed / MINUTE);
   seconds = elapsed - (minutes * MINUTE);
   g_string_append_printf (str, "%02u:%02u", minutes, seconds);
 
-  gtk_label_set_text (self->status, str->str);
+  gtk_label_set_label (self->status, str->str);
 
 #undef HOUR
 #undef MINUTE
@@ -198,17 +210,28 @@ on_call_state_changed (CuiCallDisplay *self,
 
   state = cui_call_get_state (call);
 
+  g_debug ("Call %p changed state to %s",
+           call,
+           cui_call_state_to_string (state));
+
   hang_up_style = gtk_widget_get_style_context
                     (GTK_WIDGET (self->hang_up));
 
+  /* if the state changed than the call must be responsive */
+  self->update_status_time = TRUE;
+  gtk_widget_set_sensitive (GTK_WIDGET (self->answer), TRUE);
+  gtk_widget_set_sensitive (GTK_WIDGET (self->hang_up), TRUE);
+
   #pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 
-  /* Widgets */
+  /* Widgets and call audio mode*/
   switch (state)
   {
   case CUI_CALL_STATE_INCOMING:
+    hdy_avatar_set_size (self->avatar, HDY_AVATAR_SIZE_BIG);
+    G_GNUC_FALLTHROUGH;
+
   case CUI_CALL_STATE_WAITING: /* Deprecated */
-    gtk_widget_hide (GTK_WIDGET (self->status));
     gtk_widget_hide (GTK_WIDGET (self->controls));
     gtk_widget_show (GTK_WIDGET (self->incoming_phone_call));
     gtk_widget_show (GTK_WIDGET (self->answer));
@@ -217,6 +240,10 @@ on_call_state_changed (CuiCallDisplay *self,
     break;
 
   case CUI_CALL_STATE_ACTIVE:
+    hdy_avatar_set_size (self->avatar, HDY_AVATAR_SIZE_DEFAULT);
+    self->needs_cam_reset = TRUE;
+    G_GNUC_FALLTHROUGH;
+
   case CUI_CALL_STATE_CALLING:
   case CUI_CALL_STATE_ALERTING: /* Deprecated */
   case CUI_CALL_STATE_HELD:
@@ -225,11 +252,10 @@ on_call_state_changed (CuiCallDisplay *self,
     gtk_widget_hide (GTK_WIDGET (self->answer));
     gtk_widget_hide (GTK_WIDGET (self->incoming_phone_call));
     gtk_widget_show (GTK_WIDGET (self->controls));
-    gtk_widget_show (GTK_WIDGET (self->status));
 
     gtk_widget_set_visible
       (GTK_WIDGET (self->gsm_controls),
-       state != CUI_CALL_STATE_CALLING);
+      state != CUI_CALL_STATE_CALLING);
 
     /* TODO Only switch to "call" audio mode for cellular calls */
     call_audio_select_mode_async (CALL_AUDIO_MODE_CALL,
@@ -238,9 +264,11 @@ on_call_state_changed (CuiCallDisplay *self,
     break;
 
   case CUI_CALL_STATE_DISCONNECTED:
-    call_audio_select_mode_async (CALL_AUDIO_MODE_DEFAULT,
-                                  on_libcallaudio_async_finished,
-                                  NULL);
+    if (self->needs_cam_reset)
+      call_audio_select_mode_async (CALL_AUDIO_MODE_DEFAULT,
+                                    on_libcallaudio_async_finished,
+                                    NULL);
+
     gtk_widget_set_sensitive (GTK_WIDGET (self), FALSE);
     break;
 
@@ -264,7 +292,7 @@ on_call_state_changed (CuiCallDisplay *self,
   case CUI_CALL_STATE_ALERTING: /* Deprecated */
   case CUI_CALL_STATE_HELD:
   case CUI_CALL_STATE_DISCONNECTED:
-    gtk_label_set_text (self->status, cui_call_state_to_string (state));
+    gtk_label_set_label (self->status, cui_call_state_to_string (state));
     break;
 
   case CUI_CALL_STATE_UNKNOWN:
@@ -279,8 +307,8 @@ on_call_state_changed (CuiCallDisplay *self,
 static void
 on_update_contact_information (CuiCallDisplay *self)
 {
-  GtkLabel *number_label;
-  const char *number, *display_name;
+  const char *number;
+  const char *display_name;
   gboolean show_initials;
 
   g_assert (CUI_IS_CALL_DISPLAY (self));
@@ -294,17 +322,18 @@ on_update_contact_information (CuiCallDisplay *self)
   if (IS_NULL_OR_EMPTY (display_name) == FALSE &&
       g_strcmp0 (number, display_name) != 0) {
     show_initials = TRUE;
-    number_label = self->secondary_contact_info;
+
+    gtk_label_set_label (self->primary_contact_info, display_name);
+    gtk_label_set_label (self->secondary_contact_info, number);
   } else {
     show_initials = FALSE;
-    number_label = self->primary_contact_info;
+
+    gtk_label_set_label (self->primary_contact_info, number);
+    gtk_label_set_label (self->secondary_contact_info, "");
   }
 
   hdy_avatar_set_text (self->avatar, display_name);
   hdy_avatar_set_show_initials (self->avatar, show_initials);
-
-  gtk_label_set_text (self->primary_contact_info, display_name);
-  gtk_label_set_text (number_label, number);
 }
 
 
@@ -323,6 +352,11 @@ on_time_updated (CuiCallDisplay *self)
     return;
   }
 
+  /* We don't want to overwrite the status text if there
+   * is an unfinished operation */
+  if (!self->update_status_time)
+    return;
+
   set_pretty_time (self);
 }
 
@@ -340,27 +374,39 @@ on_dialpad_revealed (CuiCallDisplay *self)
 static void
 reset_ui (CuiCallDisplay *self)
 {
+  g_assert (CUI_IS_CALL_DISPLAY (self));
+
+  g_debug ("Resetting UI");
+
+  self->update_status_time = TRUE;
   hdy_avatar_set_loadable_icon (self->avatar, NULL);
   hdy_avatar_set_text (self->avatar, "");
+  hdy_avatar_set_size (self->avatar, HDY_AVATAR_SIZE_DEFAULT);
   gtk_label_set_label (self->primary_contact_info, "");
   gtk_label_set_label (self->secondary_contact_info, "");
-  gtk_label_set_text (self->status, "");
+  gtk_label_set_label (self->status, "");
   gtk_widget_show (GTK_WIDGET (self->answer));
   gtk_widget_show (GTK_WIDGET (self->hang_up));
   gtk_widget_hide (GTK_WIDGET (self->incoming_phone_call));
   gtk_widget_show (GTK_WIDGET (self->controls));
-  gtk_widget_show (GTK_WIDGET (self->status));
   gtk_widget_show (GTK_WIDGET (self->gsm_controls));
+  gtk_widget_set_sensitive (GTK_WIDGET (self->answer), TRUE);
+  gtk_widget_set_sensitive (GTK_WIDGET (self->hang_up), TRUE);
 }
 
+
 static void
 on_call_unrefed (CuiCallDisplay *self,
                  CuiCall        *call)
 {
+  g_assert (CUI_IS_CALL_DISPLAY (self));
+
   g_debug ("Dropping call %p", call);
+
   self->call = NULL;
   self->dtmf_bind = NULL;
   self->avatar_icon_bind = NULL;
+  self->encryption_bind = NULL;
   reset_ui (self);
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_CALL]);
 }
@@ -474,7 +520,7 @@ cui_call_display_class_init (CuiCallDisplayClass *klass)
   object_class->dispose = cui_call_display_dispose;
 
   /**
-   * CuiCallDisplay:call-handle:
+   * CuiCallDisplay:call:
    *
    * An opaque handle to a call
    */
@@ -488,30 +534,31 @@ cui_call_display_class_init (CuiCallDisplayClass *klass)
   g_object_class_install_properties (object_class, PROP_LAST_PROP, props);
 
   gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/CallUI/ui/cui-call-display.ui");
+  gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, answer);
+  gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, avatar);
+  gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, controls);
   gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, dial_pad);
+  gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, dial_pad_revealer);
+  gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, encryption_indicator);
+  gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, general_controls);
+  gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, gsm_controls);
+  gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, hang_up);
   gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, incoming_phone_call);
+  gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, keypad_entry);
+  gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, mute);
   gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, primary_contact_info);
   gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, secondary_contact_info);
-  gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, avatar);
-  gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, status);
-  gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, controls);
-  gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, gsm_controls);
-  gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, general_controls);
   gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, speaker);
-  gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, mute);
-  gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, hang_up);
-  gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, answer);
-  gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, dial_pad_revealer);
-  gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, keypad_entry);
+  gtk_widget_class_bind_template_child (widget_class, CuiCallDisplay, status);
+  gtk_widget_class_bind_template_callback (widget_class, add_call_clicked_cb);
+  gtk_widget_class_bind_template_callback (widget_class, block_delete_cb);
+  gtk_widget_class_bind_template_callback (widget_class, hide_dial_pad_clicked_cb);
+  gtk_widget_class_bind_template_callback (widget_class, hold_toggled_cb);
+  gtk_widget_class_bind_template_callback (widget_class, insert_text_cb);
+  gtk_widget_class_bind_template_callback (widget_class, mute_toggled_cb);
   gtk_widget_class_bind_template_callback (widget_class, on_answer_clicked);
   gtk_widget_class_bind_template_callback (widget_class, on_hang_up_clicked);
-  gtk_widget_class_bind_template_callback (widget_class, hold_toggled_cb);
-  gtk_widget_class_bind_template_callback (widget_class, mute_toggled_cb);
   gtk_widget_class_bind_template_callback (widget_class, speaker_toggled_cb);
-  gtk_widget_class_bind_template_callback (widget_class, add_call_clicked_cb);
-  gtk_widget_class_bind_template_callback (widget_class, hide_dial_pad_clicked_cb);
-  gtk_widget_class_bind_template_callback (widget_class, block_delete_cb);
-  gtk_widget_class_bind_template_callback (widget_class, insert_text_cb);
 
   gtk_widget_class_set_css_name (widget_class, "cui-call-display");
 }
@@ -549,8 +596,8 @@ cui_call_display_new (CuiCall *call)
  * cui_call_display_get_call:
  * @self: The call display
  *
- * Returns the current [class@CuiCall]
- * Returns: (transfer none) (nullable): The current [class@CuiCall].
+ * Returns the current [iface@CuiCall]
+ * Returns: (transfer none) (nullable): The current [iface@CuiCall].
  */
 CuiCall *
 cui_call_display_get_call (CuiCallDisplay *self)
@@ -565,7 +612,7 @@ cui_call_display_get_call (CuiCallDisplay *self)
  * @self: The call display
  * @call: (nullable): The current call
  *
- * Set a call. The current call will be removed form the display and the
+ * Set a [iface@CuiCall]. The current call will be removed form the display and the
  * new call displayed instead.
  */
 void
@@ -582,10 +629,15 @@ cui_call_display_set_call (CuiCallDisplay *self, CuiCall *call)
     g_signal_handlers_disconnect_by_data (self->call, self);
     g_clear_pointer (&self->dtmf_bind, g_binding_unbind);
     g_clear_pointer (&self->avatar_icon_bind, g_binding_unbind);
+    g_clear_pointer (&self->encryption_bind, g_binding_unbind);
   }
 
+  self->update_status_time = TRUE;
+  self->needs_cam_reset = FALSE;
+
   self->call = call;
   gtk_widget_set_sensitive (GTK_WIDGET (self), !!self->call);
+
   if (self->call == NULL) {
     reset_ui (self);
     return;
@@ -620,10 +672,15 @@ cui_call_display_set_call (CuiCallDisplay *self, CuiCall *call)
                                             G_BINDING_SYNC_CREATE);
 
   self->avatar_icon_bind = g_object_bind_property (call,
-						   "avatar-icon",
-						   self->avatar,
-						   "loadable-icon",
-						   G_BINDING_SYNC_CREATE);
+                                                   "avatar-icon",
+                                                   self->avatar,
+                                                   "loadable-icon",
+                                                   G_BINDING_SYNC_CREATE);
+  self->encryption_bind = g_object_bind_property (call,
+                                                  "encrypted",
+                                                  self->encryption_indicator,
+                                                  "encrypted",
+                                                  G_BINDING_SYNC_CREATE);
 
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_CALL]);
 }
