@@ -6,6 +6,7 @@
  * Author: Guido Günther <agx@sigxcpu.org>
  */
 
+#include "phosh-config.h"
 #include "testlib.h"
 #include "testlib-head-stub.h"
 
@@ -24,6 +25,16 @@
 
 #define STARTUP_TIMEOUT 10
 
+static PhoshTestCompositorState *_state;
+#ifndef PHOSH_USES_ASAN
+/**
+ * SIBABRT: raised on failed g_assert*
+ * SIGTRAP: raised with G_DEBUG=fatal-{warnings,criticals}
+ * SIGSEGV: the usual suspect
+ */
+static int handled_signals[] = { SIGABRT, SIGSEGV, SIGTRAP };
+#endif
+
 typedef struct _PhocOutputWatch {
   char      *socket;
   GMainLoop *loop;
@@ -150,6 +161,21 @@ phosh_test_get_monitor(void)
 }
 
 
+#ifndef PHOSH_USES_ASAN
+static void
+abrt_handler (int signal)
+{
+  const struct sigaction act = { .sa_handler = SIG_DFL };
+
+  if (_state->pid)
+    kill (_state->pid, SIGTERM);
+
+  /* Make sure the default handler runs */
+  sigaction (signal, &act, NULL);
+}
+#endif
+
+
 PhoshTestCompositorState *
 phosh_test_compositor_new (gboolean heads_stub)
 {
@@ -238,15 +264,35 @@ phosh_test_compositor_new (gboolean heads_stub)
   if (heads_stub)
     phosh_test_head_stub_init (state->wl);
 
+  g_assert_null (_state);
+  _state = state;
+
+#ifndef PHOSH_USES_ASAN
+  /* Install a ABRT handler that terminates the compositor quickly as we otherwise have
+     to wait for a timeout */
+  for (int i = 0; i < G_N_ELEMENTS (handled_signals); i++) {
+    int signal = handled_signals[i];
+    const struct sigaction act = { .sa_handler = abrt_handler };
+    struct sigaction old_act;
+
+    sigaction (signal, NULL, &old_act);
+    g_assert (old_act.sa_handler == SIG_DFL);
+
+    sigaction (signal, &act, NULL);
+  }
+#endif
+
   return state;
 }
 
 void
 phosh_test_compositor_free (PhoshTestCompositorState *state)
 {
-  if (!state)
+  if (state == NULL)
     return;
 
+  g_assert_true (state == _state);
+
   phosh_test_head_stub_destroy ();
 
   g_assert_finalize_object (state->wl);
@@ -255,7 +301,16 @@ phosh_test_compositor_free (PhoshTestCompositorState *state)
   kill (state->pid, SIGTERM);
   g_spawn_close_pid (state->pid);
 
-  g_clear_pointer (&state, g_free);
+#ifndef PHOSH_USES_ASAN
+  for (int i = 0; i < G_N_ELEMENTS (handled_signals); i++) {
+    struct sigaction act = { .sa_handler = SIG_DFL };
+    int signal = handled_signals[i];
+
+    sigaction (signal, &act, NULL);
+  }
+#endif
+
+  g_clear_pointer (&_state, g_free);
 }
 
 /**
@@ -329,6 +384,10 @@ phosh_test_keyboard_press_modifiers (struct zwp_virtual_keyboard_v1 *keyboard,
   case KEY_RIGHTCTRL:
     modifiers |= (1 << 2);
     break;
+  case KEY_LEFTALT:
+  case KEY_RIGHTALT:
+    modifiers |= (1 << 3);
+    break;
   case KEY_LEFTMETA:
   case KEY_RIGHTMETA:
     modifiers |= (1 << 6);
